@@ -13,34 +13,42 @@ The data can be viewed in a terminal with
 
     python -m galcheat
 
-To access the quantities, use the main
-dictionary called `survey_info` containing
-`Survey` objects
+To access the quantities, retrieve the
+`Survey` objects with `get_survey`.
 
-    >>> from galcheat import survey_info
-    >>> Rubin = survey_info['Rubin']
+    >>> from galcheat import get_survey
+    >>> Rubin = get_survey('Rubin')
     >>> Rubin.mirror_diameter
     <Quantity 8.36 m>
 
-Each `Survey` contains its own `Filter` list
-accessible from the `Survey`
+Each `Survey` contains a list of filters
+whose names can be obtained as
+
+    >>> Rubin.available_filters
+
+Each `Filter` class is then accessible either
+as an attribute from the `Survey`
 
     >>> u_filter = Rubin.filters.u
 
-or as an ordered list
+or through a method
 
-    >>> filters = Rubin.get_filters()
-    >>> u_filter = filters[0]
+    >>> u_filter = Rubin.get_filter('u')
 
-And parameter values can be converted to any
-physical units using the `astropy.units` scheme
+For a given survey, a dictionary of the available
+filters is returned by
+
+    >>> Rubin.get_filters()
+
+Parameter values can be converted to any physical
+units using the `astropy.units` scheme
 
     >>> u_filter.psf_fwhm
     <Quantity 0.859 arcsec>
     >>> u_filter.value
     0.859
 
-    >>> from astropy import units as u
+    >>> import astropy.units as u
     >>> u_filter.psf_fwhm.to(u.arcmin).value
 or
     >>> u_filter.psf_fwhm.to_value(u.arcmin)
@@ -56,8 +64,11 @@ from pathlib import Path
 
 from galcheat.survey import Survey
 
-_BASEDIR = Path(__file__).parent.resolve()
+__all__ = ["available_surveys", "get_filter", "get_survey"]
 
-survey_info = {
+_BASEDIR = Path(__file__).parent.resolve()
+_survey_info = {
     path.stem: Survey.from_yaml(path) for path in _BASEDIR.glob("data/*.yaml")
 }
+
+from galcheat.helpers import available_surveys, get_filter, get_survey  # noqa
