@@ -8,12 +8,11 @@ from astropy.units import Quantity
 @dataclass
 class Filter:
     name: str
-    pixel_scale: Quantity
     psf_fwhm: Quantity
     zeropoint: Quantity
     extinction: Quantity
     sky_brightness: Quantity
-    exposure_time: Optional[Quantity] = None
+    exposure_time: Quantity
     central_wavelength: Optional[Quantity] = None
 
     @classmethod
@@ -34,19 +33,16 @@ class Filter:
 
         """
         name = filter_info["name"]
-        pixel_scale = filter_info["pixel_scale"] * (u.arcsec / u.pix)
         psf_fwhm = filter_info["psf_fwhm"] * u.arcsec
         zeropoint = filter_info["zeropoint"] * u.mag
-        extinction = filter_info["extinction"] * u.dimensionless_unscaled
+        extinction = filter_info["extinction"] * u.mag
         sky_brightness = filter_info["sky_brightness"] * (u.mag / u.arcsec ** 2)
-        exposure_time = filter_info.get("exposure_time")
-        exposure_time = exposure_time if exposure_time is None else exposure_time * u.s
+        exposure_time = filter_info["exp_time"] * u.s
         wavelength = filter_info.get("central_wavelength")
         wavelength = wavelength if wavelength is None else wavelength * u.nm
 
         return cls(
             name,
-            pixel_scale,
             psf_fwhm,
             zeropoint,
             extinction,
